@@ -4,19 +4,29 @@
 
 #' Perform Sensitivity Analysis and Interpretable ML methods
 #'
-#' As the final step in the MLwrap package workflow, this function performs Sensitivity Analysis (SA) on a fitted
-#' ML model stored in an `analysis_object` (in the examples, e.g., tidy_object). It evaluates the importance
-#' of features using various methods such as Permutation Feature Importance (PFI), SHAP (SHapley Additive
-#' exPlanations), Integrated Gradients, Olden sensitivity analysis, and Sobol indices. The function generates
-#' numerical results and visualizations (e.g., bar plots, box plots, beeswarm plots) to help interpret the impact
-#' of each feature on the model's predictions for both regression and classification tasks, providing critical
-#' insights after model training and evaluation.
+#' @name sensitivity_analysis
+#' @aliases sensitivity_analysis
 #'
-#' Following the steps of data preprocessing, model fitting, and performance assessment in the MLwrap pipeline,
-#' *sensitivity_analysis()* processes the training and test data using the preprocessing recipe stored in the
-#' analysis_object, applies the specified SA methods, and stores the results within the analysis_object. It
-#' supports different metrics for evaluation and handles multi-class classification by producing class-specific
-#' analyses and plots, ensuring a comprehensive understanding of model behavior (Iooss & Lemaître, 2015).
+#' @description
+#' As the final step in the MLwrap package workflow, this function performs
+#' Sensitivity Analysis (SA) on a fitted ML model stored in an `analysis_object`
+#' (in the examples, e.g., tidy_object). It evaluates the importance of features
+#' using various methods such as Permutation Feature Importance (PFI), SHAP
+#' (SHapley Additive exPlanations), Integrated Gradients, Olden sensitivity
+#' analysis, and Sobol indices. The function generates numerical results and
+#' visualizations (e.g., bar plots, box plots, beeswarm plots) to help interpret
+#' the impact of each feature on the model's predictions for both regression and
+#' classification tasks, providing critical insights after model training and
+#' evaluation.
+#'
+#' Following the steps of data preprocessing, model fitting, and performance
+#' assessment in the MLwrap pipeline, *sensitivity_analysis()* processes the
+#' training and test data using the preprocessing recipe stored in the
+#' analysis_object, applies the specified SA methods, and stores the results
+#' within the analysis_object. It supports different metrics for evaluation and
+#' handles multi-class classification by producing class-specific analyses and
+#' plots, ensuring a comprehensive understanding of model behavior
+#' (Iooss & Lemaître, 2015).
 #'
 #' @param analysis_object analysis_object created from fine_tuning function.
 #' @param methods Method to be used. A string of the method name: "PFI" (Permutation Feature Importance),
@@ -26,81 +36,79 @@
 #'  A string of the name of metric (see Metrics).
 #'
 #' @details
-#' As the concluding phase of the MLwrap workflow—after data preparation, model training, and evaluation—this
-#' function enables users to interpret their models by quantifying and visualizing feature importance. It first
-#' validates the input arguments using `check_args_sensitivity_analysis()`. Then, it preprocesses the training
-#' and test data using the recipe stored in `analysis_object$transformer`. Depending on the specified `methods`,
-#' it calculates feature importance using:
-#' - **PFI (Permutation Feature Importance):** Assesses importance by shuffling feature values and measuring
-#'                                             the change in model performance (using the specified or default
-#'                                             `metric`).
-#' - **SHAP (SHapley Additive exPlanations):** Computes SHAP values to explain individual predictions by
-#'                                             attributing contributions to each feature.
-#' - **Integrated Gradients:** Evaluates feature importance by integrating gradients of the model's output
-#'                             with respect to input features.
-#' - **Olden:** Calculates sensitivity based on connection weights, typically for neural network models, to
-#'             determine feature contributions.
-#' - **Sobol_Jansen:** Performs variance-based global sensitivity analysis by decomposing the model output variance
-#'                     into contributions from individual features and their interactions, quantifying how much each
-#'                     feature and combination of features accounts for the variability in predictions. Only for
-#'                     continuous outcomes, not for categorical. Specifically, estimates first-order and total-order
-#'                     Sobol' sensitivity indices simultaneously using the Jansen (1999) Monte Carlo estimator.
+#' As the concluding phase of the MLwrap workflow—after data preparation, model
+#' training, and evaluation—this function enables users to interpret their
+#' models by quantifying and visualizing feature importance. It first validates
+#' the input arguments using `check_args_sensitivity_analysis()`. Then, it
+#' preprocesses the training and test data using the recipe stored in
+#' `analysis_object$transformer`. Depending on the specified `methods`, it
+#' calculates feature importance using:
+#' - **PFI (Permutation Feature Importance):** Assesses importance by shuffling
+#'     feature values and measuring the change in model performance (using the
+#'     specified or default `metric`).
+#' - **SHAP (SHapley Additive exPlanations):** Computes SHAP values to explain
+#'     individual predictions by attributing contributions to each feature.
+#' - **Integrated Gradients:** Evaluates feature importance by integrating
+#'     gradients of the model's output with respect to input features.
+#' - **Olden:** Calculates sensitivity based on connection weights, typically
+#'     for neural network models, to determine feature contributions.
+#' - **Sobol_Jansen:** Performs variance-based global sensitivity analysis by
+#'     decomposing the model output variance into contributions from individual
+#'     features and their interactions, quantifying how much each feature and
+#'     combination of features accounts for the variability in predictions.
+#'     Only for continuous outcomes, not for categorical. Specifically,
+#'     estimates first-order and total-order Sobol' sensitivity indices
+#'     simultaneously using the Jansen (1999) Monte Carlo estimator.
 #'
-#' For classification tasks with more than two outcome levels, the function generates separate results and plots
-#' for each class. Visualizations include bar plots for importance metrics, box plots for distribution of values,
-#' and beeswarm plots for detailed feature impact across observations. All results are stored in the `analysis_object`
-#' under the `sensitivity_analysis` slot, finalizing the MLwrap pipeline with a deep understanding of model drivers.
-#' @returns An updated `analysis_object` with the results of the sensitivity analysis stored in the
-#' `sensitivity_analysis` slot as a list. Each method's results are accessible under named elements
-#' (e.g., `sensitivity_analysis[["PFI"]]`). Additionally, the function produces various plots (bar plots,
-#' box plots, beeswarm plots) for visual interpretation of feature importance, tailored to the task type
-#' and number of outcome levels, completing the MLwrap workflow with actionable model insights.
+#' For classification tasks with more than two outcome levels, the function
+#' generates separate results and plots for each class. Visualizations include
+#' bar plots for importance metrics, box plots for distribution of values, and
+#' beeswarm plots for detailed feature impact across observations. All results
+#' are stored in the `analysis_object` under the `sensitivity_analysis` slot,
+#' finalizing the MLwrap pipeline with a deep understanding of model drivers.
+#' @returns An updated `analysis_object` with the results of the sensitivity
+#' analysis stored in the `sensitivity_analysis` slot as a list.
+#' Each method's results are accessible under named elements (e.g.,
+#' `sensitivity_analysis[["PFI"]]`). Additionally, the function produces various
+#' plots (bar plots, box plots, beeswarm plots) for visual interpretation of
+#' feature importance, tailored to the task type and number of outcome levels,
+#' completing the MLwrap workflow with actionable model insights.
 #' @examples
 #' # Example: Using PFI
 #'
-#' library(MLwrap)
-#'
-#' data(sim_data) # sim_data is a simulated dataset with psychological variables
-#'
+#' set.seed(123) # For reproducibility
 #' wrap_object <- preprocessing(
-#'        df = sim_data[1:500 ,],
-#'        formula = psych_well ~ depression + emot_intel + life_sat,
+#'        df = sim_data,
+#'        formula = psych_well ~ depression + life_sat,
 #'        task = "regression"
 #'        )
-#'
 #' wrap_object <- build_model(
 #'                analysis_object = wrap_object,
 #'                model_name = "Random Forest",
 #'                hyperparameters = list(
-#'                                  mtry = 3,
-#'                                  trees = 5
+#'                                  mtry = 2,
+#'                                  trees = 3
 #'                                  )
 #'                            )
-#'
 #' wrap_object <- fine_tuning(wrap_object,
 #'                 tuner = "Grid Search CV",
 #'                 metrics = c("rmse")
 #'                 )
-#'
-#'
 #' wrap_object <- sensitivity_analysis(wrap_object, methods = "PFI")
 #'
 #' # Extracting Results
 #'
 #' table_pfi <- table_pfi_results(wrap_object)
 #'
-#' # Plotting PFI Results
-#'
-#' wrap_object %>%
-#'     plot_pfi()
-#'
 #' @references
-#' Iooss, B., & Lemaître, P. (2015). A review on global sensitivity analysis methods. In C. Meloni & G. Dellino
-#' (Eds.), *Uncertainty Management in Simulation-Optimization of Complex Systems: Algorithms and Applications*
+#' Iooss, B., & Lemaître, P. (2015). A review on global sensitivity analysis
+#' methods. In C. Meloni & G. Dellino (Eds.), *Uncertainty Management in
+#' Simulation-Optimization of Complex Systems: Algorithms and Applications*
 #' (pp. 101-122). Springer. https://doi.org/10.1007/978-1-4899-7547-8_5
 #'
-#' Jansen, M. J. W. (1999). Analysis of variance designs for model output. Computer Physics Communications,
-#' 117(1-2), 35–43. https://doi.org/10.1016/S0010-4655(98)00154-4
+#' Jansen, M. J. W. (1999). Analysis of variance designs for model output.
+#' Computer Physics Communications, 117(1-2), 35–43.
+#' https://doi.org/10.1016/S0010-4655(98)00154-4
 #' @export
 sensitivity_analysis <- function(analysis_object, methods = c("PFI"), metric = NULL){
 
@@ -521,7 +529,7 @@ plot_barplot <- function(X, func = NULL, func_se = stats::sd, title, x_label) {
       ggplot2::geom_col(fill = "steelblue") +
       ggplot2::geom_errorbar(ggplot2::aes(xmin = Importance - StDev, xmax = Importance + StDev), width = 0.2) +
       ggplot2::geom_text(ggplot2::aes(label = paste0(round(Importance, 3), " (", round(StDev, 3), ")")),
-                vjust =  -1.5,
+                vjust =  -0.25,
                 hjust = -0.2) +
       ggplot2::labs(
         x = x_label,
@@ -620,37 +628,42 @@ plot_boxplot <- function(X, title, y_label){
 
 ###### Beeswarm
 
-plot_beeswarm <- function(X_vals, X_orig, title, x_label){
+plot_beeswarm <- function(X_vals, X_orig, title, x_label, color_quantiles = c(0.02, 0.98)) {
 
   order_df <- tibble::tibble(
     variable = base::colnames(X_vals),
     value = base::sapply(X_vals, function(x) mean(abs(x)))
   )
 
-
-  summary_df <- X_vals %>%
-    tidyr::pivot_longer(cols = dplyr::everything(), names_to = "variable", values_to = "value")
+  summary_df <- X_vals |>
+    tidyr::pivot_longer(dplyr::everything(), names_to = "variable", values_to = "value")
 
   summary_df$variable <- factor(summary_df$variable,
-                            levels = order_df$variable[order(order_df$value, decreasing = F)])
+                                levels = order_df$variable[order(order_df$value, decreasing = FALSE)])
 
-  X <- X_orig %>%
-    tidyr::pivot_longer(cols = dplyr::everything(), names_to = "variable", values_to = "val_color")
+  X <- X_orig |>
+    tidyr::pivot_longer(dplyr::everything(), names_to = "variable", values_to = "val_color")
 
   X$variable <- factor(X$variable,
-                                 levels = order_df$variable[order(order_df$value, decreasing = F)])
+                       levels = order_df$variable[order(order_df$value, decreasing = FALSE)])
 
-  summary_df["val_color"] = X["val_color"]
+  summary_df[["val_color"]] <- X[["val_color"]]
 
+  # 5th / 95th percentiles for the color scale
+  q <- stats::quantile(summary_df$val_color, probs = color_quantiles, na.rm = TRUE, names = FALSE)
+  if (diff(q) == 0) q <- q + c(-1e-8, 1e-8)  # guard for constant color
 
-  p <- ggplot2::ggplot(summary_df, ggplot2::aes(x=value, y=variable, color = val_color)) +
-    ggbeeswarm::geom_quasirandom(bandwidth = 0.2, method = "pseudorandom", cex = 2, orientation = 'x') +
-    ggplot2::labs(x = x_label, y = "Feature" ,title = title) +
+  p <- ggplot2::ggplot(summary_df, ggplot2::aes(x = value, y = variable, color = val_color)) +
+    ggbeeswarm::geom_quasirandom(bandwidth = 0.2, method = "pseudorandom", cex = 2, orientation = "x") +
+    ggplot2::labs(x = x_label, y = "Feature", title = title) +
     ggplot2::theme_grey() +
-    ggplot2::scale_color_viridis_c(option = "A")
+    ggplot2::scale_color_viridis_c(
+      option = "A",
+      limits = q,                 # clamp to 5th/95th pct
+      oob = scales::squish        # keep points, squash extremes to ends
+    )
 
   return(p)
-
 }
 
 ###########################
